==> haskell-smallcheck-1.2.1.1-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 smallcheck
version:              1.2.1.1
visibility:           public
id:                   smallcheck-1.2.1.1-4p2Dwunx6WQ3QFdxN6svSY
key:                  smallcheck-1.2.1.1-4p2Dwunx6WQ3QFdxN6svSY
license:              BSD-3-Clause
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Colin Runciman, Roman Cheplyaka
homepage:             https://github.com/Bodigrim/smallcheck
synopsis:             A property-based testing library
description:
    As of 2023, this library is largely obsolete: arbitrary test generators
    with shrinking such as [falsify](https://hackage.haskell.org/package/falsify)
    offer much better user experience.

    SmallCheck is a testing library that allows to verify properties
    for all test cases up to some depth. The test cases are generated
    automatically by SmallCheck.

category:             Testing
abi:                  5d31ceda32ef10d373f8f7c33b49b416
exposed:              True
exposed-modules:
    Test.SmallCheck Test.SmallCheck.Drivers Test.SmallCheck.Series

hidden-modules:
    Test.SmallCheck.Property Test.SmallCheck.SeriesMonad
    Test.SmallCheck.Property.Result

import-dirs:          /usr/lib/ghc-9.2.8/site-local/smallcheck-1.2.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/smallcheck-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-smallcheck
hs-libraries:         HSsmallcheck-1.2.1.1-4p2Dwunx6WQ3QFdxN6svSY
depends:
    base-4.16.4.0 logict-0.7.1.0-vSThXOdbcC73aHlgzIYoM mtl-2.2.2
    pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/haskell-smallcheck/html/smallcheck.haddock
haddock-html:         /usr/share/doc/haskell-smallcheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-smallcheck-1.2.1.1-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 smallcheck
version:              1.2.1.1
visibility:           public
id:                   smallcheck-1.2.1.1-Ks9q7P6zWtN5gltGxXk9cQ
key:                  smallcheck-1.2.1.1-Ks9q7P6zWtN5gltGxXk9cQ
license:              BSD-3-Clause
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Colin Runciman, Roman Cheplyaka
homepage:             https://github.com/Bodigrim/smallcheck
synopsis:             A property-based testing library
description:
    As of 2023, this library is largely obsolete: arbitrary test generators
    with shrinking such as [falsify](https://hackage.haskell.org/package/falsify)
    offer much better user experience.

    SmallCheck is a testing library that allows to verify properties
    for all test cases up to some depth. The test cases are generated
    automatically by SmallCheck.

category:             Testing
abi:                  143b9e800275d435bfe446c80b04988d
exposed:              True
exposed-modules:
    Test.SmallCheck Test.SmallCheck.Drivers Test.SmallCheck.Series

hidden-modules:
    Test.SmallCheck.Property Test.SmallCheck.SeriesMonad
    Test.SmallCheck.Property.Result

import-dirs:          /usr/lib/ghc-9.4.8/site-local/smallcheck-1.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/smallcheck-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/smallcheck-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-smallcheck
hs-libraries:         HSsmallcheck-1.2.1.1-Ks9q7P6zWtN5gltGxXk9cQ
depends:
    base-4.17.2.1 logict-0.7.1.0-IY7g6i7G1XO1L8kO0y23E6 mtl-2.2.2
    pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/haskell-smallcheck/html/smallcheck.haddock
haddock-html:         /usr/share/doc/haskell-smallcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
